Status:  [![Build Status](https://travis-ci.org/dante-signal31/vdist.svg?branch=staging)](https://travis-ci.org/dante-signal31/vdist)

Welcome to the home of vdist, a tool that lets you create OS packages from your Python applications in a clean and self contained manner. It uses [Docker](https://www.docker.com/) and [fpm](https://github.com/jordansissel/fpm) under the hood, and it uses [Jinja2](http://jinja.pocoo.org/docs/dev/) to render its templates for each individual target OS.

vdist should work just fine in most cases, but issues, feature requests, pull requests etc. are very welcome!

The official documentation for vdist can be found on [ReadTheDocs](http://vdistdocs.readthedocs.io/en/latest/)
